# REL11: How do you design your workload to withstand component failures?

## References

- [AWS REL11](https://docs.aws.amazon.com/wellarchitected/latest/framework/rel-11.html)

## Date

2025-11-27

## Focus Area

Failure Management

## Tổng quan

REL11 tập trung vào designing for component failures.

## Best Practices

### REL11-BP01: Monitor all workload components
Full monitoring.

### REL11-BP02: Graceful degradation
Fallbacks.

### REL11-BP03: Automate healing on all layers
Self-healing.

### REL11-BP04: Use static stability
Pre-provisioned capacity.

### REL11-BP05: Send notifications when events impact availability
Alerting.

## Checklist

- [ ] Components monitored
- [ ] Graceful degradation
- [ ] Self-healing implemented
- [ ] Availability alerts
